You are viewing a plain text version of this content. The canonical link for it is here.
Posted to axis-cvs@ws.apache.org by pi...@apache.org on 2007/03/30 20:47:02 UTC

svn commit: r524229 [1/2] - in /webservices/axis2/trunk/c: axiom/test/om/ axiom/test/soap/ include/ modules/core/deployment/ modules/core/transport/http/sender/ modules/core/transport/http/sender/libcurl/ modules/core/transport/http/server/IIS/ modules...

Author: pini
Date: Fri Mar 30 11:46:59 2007
New Revision: 524229

URL: http://svn.apache.org/viewvc?view=rev&rev=524229
Log:
Fixing jira issue 292

Added:
    webservices/axis2/trunk/c/util/include/axutil_generic_obj.h
      - copied, changed from r524208, webservices/axis2/trunk/c/util/include/axis2_generic_obj.h
    webservices/axis2/trunk/c/util/include/axutil_linked_list.h
      - copied, changed from r524188, webservices/axis2/trunk/c/util/include/axis2_linked_list.h
    webservices/axis2/trunk/c/util/include/axutil_log.h
      - copied, changed from r524179, webservices/axis2/trunk/c/util/include/axis2_log.h
    webservices/axis2/trunk/c/util/include/axutil_log_default.h
      - copied, changed from r524179, webservices/axis2/trunk/c/util/include/axis2_log_default.h
Removed:
    webservices/axis2/trunk/c/util/include/axis2_generic_obj.h
    webservices/axis2/trunk/c/util/include/axis2_linked_list.h
    webservices/axis2/trunk/c/util/include/axis2_log.h
    webservices/axis2/trunk/c/util/include/axis2_log_default.h
Modified:
    webservices/axis2/trunk/c/axiom/test/om/test_om.c
    webservices/axis2/trunk/c/axiom/test/soap/test_soap.c
    webservices/axis2/trunk/c/include/axis2_util.h
    webservices/axis2/trunk/c/modules/core/deployment/desc_builder.c
    webservices/axis2/trunk/c/modules/core/transport/http/sender/axis2_http_sender_util.h
    webservices/axis2/trunk/c/modules/core/transport/http/sender/http_sender.c
    webservices/axis2/trunk/c/modules/core/transport/http/sender/libcurl/axis2_libcurl.c
    webservices/axis2/trunk/c/modules/core/transport/http/sender/libcurl/axis2_libcurl.h
    webservices/axis2/trunk/c/modules/core/transport/http/sender/sender_util.c
    webservices/axis2/trunk/c/modules/core/transport/http/server/IIS/axis2_isapi_plugin.c
    webservices/axis2/trunk/c/modules/core/transport/http/server/apache2/mod_axis2.c
    webservices/axis2/trunk/c/modules/core/transport/http/server/simple_axis2_server/http_server_main.c
    webservices/axis2/trunk/c/modules/mod_log/log_in_handler.c
    webservices/axis2/trunk/c/modules/mod_log/log_out_handler.c
    webservices/axis2/trunk/c/modules/mod_log/mod_log.c
    webservices/axis2/trunk/c/modules/mod_log/mod_log.h
    webservices/axis2/trunk/c/samples/client/dynamic_client/dynamic_client.c
    webservices/axis2/trunk/c/samples/client/dynamic_client/test.c
    webservices/axis2/trunk/c/samples/server/Calculator/calc.h
    webservices/axis2/trunk/c/samples/server/echo/echo.h
    webservices/axis2/trunk/c/samples/server/math/math.h
    webservices/axis2/trunk/c/samples/server/mtom/mtom.h
    webservices/axis2/trunk/c/samples/server/notify/notify.h
    webservices/axis2/trunk/c/samples/server/sg_math/add.h
    webservices/axis2/trunk/c/samples/server/sg_math/div.h
    webservices/axis2/trunk/c/samples/server/sg_math/mul.h
    webservices/axis2/trunk/c/samples/server/sg_math/sub.h
    webservices/axis2/trunk/c/savan/samples/server/listener/listener.h
    webservices/axis2/trunk/c/savan/samples/server/publisher/publisher.h
    webservices/axis2/trunk/c/test/core/deployment/test_deployment.c
    webservices/axis2/trunk/c/tools/codegen/samples/server/calculator/axis2_skel_calculator.h
    webservices/axis2/trunk/c/tools/codegen/samples/server/interop_test_svc/axis2_skel_interop_test_port_type_doc_service.h
    webservices/axis2/trunk/c/tools/tcpmon/src/tcpmon.c
    webservices/axis2/trunk/c/util/include/axutil_env.h
    webservices/axis2/trunk/c/util/include/platforms/unix/axis2_unix.h
    webservices/axis2/trunk/c/util/include/platforms/windows/axis2_windows.h
    webservices/axis2/trunk/c/util/src/env.c
    webservices/axis2/trunk/c/util/src/generic_obj.c
    webservices/axis2/trunk/c/util/src/linked_list.c
    webservices/axis2/trunk/c/util/src/log.c
    webservices/axis2/trunk/c/util/src/param.c
    webservices/axis2/trunk/c/util/test/util/test_log.c
    webservices/axis2/trunk/c/util/test/util/test_log.h
    webservices/axis2/trunk/c/util/test/util/test_string.c
    webservices/axis2/trunk/c/util/test/util/test_thread.c
    webservices/axis2/trunk/c/util/test/util/test_util.c
    webservices/axis2/trunk/c/woden/include/woden_element_decl.h
    webservices/axis2/trunk/c/woden/include/woden_generic_obj.h
    webservices/axis2/trunk/c/woden/include/woden_property_element.h
    webservices/axis2/trunk/c/woden/include/woden_xml_attr.h
    webservices/axis2/trunk/c/woden/samples/test_wsdl2.c
    webservices/axis2/trunk/c/woden/samples/wsdl10/test_wsdl1.c
    webservices/axis2/trunk/c/woden/src/builder/woden_reader.c
    webservices/axis2/trunk/c/woden/src/builder/wsdl10/woden_wsdl10_reader.c
    webservices/axis2/trunk/c/woden/src/wsdl/woden_element_decl.c
    webservices/axis2/trunk/c/woden/src/wsdl/woden_property.c
    webservices/axis2/trunk/c/woden/src/wsdl/woden_type_def.c
    webservices/axis2/trunk/c/woden/src/xml/woden_qname_list_or_token_any_attr.c
    webservices/axis2/trunk/c/woden/src/xml/woden_qname_or_token_any_attr.c
    webservices/axis2/trunk/c/woden/src/xml/woden_xml_attr.c

Modified: webservices/axis2/trunk/c/axiom/test/om/test_om.c
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/axiom/test/om/test_om.c?view=diff&rev=524229&r1=524228&r2=524229
==============================================================================
--- webservices/axis2/trunk/c/axiom/test/om/test_om.c (original)
+++ webservices/axis2/trunk/c/axiom/test/om/test_om.c Fri Mar 30 11:46:59 2007
@@ -22,7 +22,7 @@
 #include <axiom_text.h>
 #include <axiom_data_source.h>
 #include <axis2_stream.h>
-#include <axis2_log_default.h>
+#include <axutil_log_default.h>
 #include <axutil_error_default.h>
 #include <axiom_xml_reader.h>
 #include <stdio.h>
@@ -37,7 +37,7 @@
 axutil_env_t *environment = NULL;
 axis2_stream_t *stream = NULL;
 axutil_error_t *error = NULL;
-axis2_log_t *axis_log     = NULL;
+axutil_log_t *axis_log     = NULL;
 FILE *f = NULL;
 /** a method that demonstrate creating a om model using an xml file */
 
@@ -306,7 +306,7 @@
     if (argc > 1)
         file_name = argv[1];
     allocator = axutil_allocator_init(NULL);
-    axis_log = axis2_log_create(allocator, NULL, NULL);
+    axis_log = axutil_log_create(allocator, NULL, NULL);
     error = axutil_error_create(allocator);
 
     environment = axutil_env_create_with_error_log(allocator, error,  axis_log);

Modified: webservices/axis2/trunk/c/axiom/test/soap/test_soap.c
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/axiom/test/soap/test_soap.c?view=diff&rev=524229&r1=524228&r2=524229
==============================================================================
--- webservices/axis2/trunk/c/axiom/test/soap/test_soap.c (original)
+++ webservices/axis2/trunk/c/axiom/test/soap/test_soap.c Fri Mar 30 11:46:59 2007
@@ -22,7 +22,7 @@
 #include <axiom_element.h>
 #include <axiom_text.h>
 #include <axis2_stream.h>
-#include <axis2_log_default.h>
+#include <axutil_log_default.h>
 #include <axutil_error_default.h>
 #include <axiom_xml_reader.h>
 #include <stdio.h>
@@ -400,7 +400,7 @@
     axutil_env_t *env = NULL;
     axutil_allocator_t *allocator = NULL;
     axutil_error_t *error = NULL;
-    axis2_log_t *log = NULL;
+    axutil_log_t *log = NULL;
     const axis2_char_t *uri = AXIOM_SOAP12_SOAP_ENVELOPE_NAMESPACE_URI;
     const char *filename = "./../../resources/xml/soap/test.xml";
     if (argc > 1)
@@ -413,7 +413,7 @@
             uri = AXIOM_SOAP12_SOAP_ENVELOPE_NAMESPACE_URI;
     }
     allocator = axutil_allocator_init(NULL);
-    log = axis2_log_create(allocator, NULL, "test_soap.log");
+    log = axutil_log_create(allocator, NULL, "test_soap.log");
     log->level = AXIS2_LOG_LEVEL_DEBUG;
     error = axutil_error_create(allocator);
     env = axutil_env_create_with_error_log(allocator, error,  log);

Modified: webservices/axis2/trunk/c/include/axis2_util.h
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/include/axis2_util.h?view=diff&rev=524229&r1=524228&r2=524229
==============================================================================
--- webservices/axis2/trunk/c/include/axis2_util.h (original)
+++ webservices/axis2/trunk/c/include/axis2_util.h Fri Mar 30 11:46:59 2007
@@ -28,8 +28,8 @@
 #include <axutil_file.h>
 #include <axutil_file_handler.h>
 #include <axutil_hash.h>
-#include <axis2_linked_list.h>
-#include <axis2_log.h>
+#include <axutil_linked_list.h>
+#include <axutil_log.h>
 #include <axis2_network_handler.h>
 #include <axis2_param.h>
 #include <axis2_param_container.h>

Modified: webservices/axis2/trunk/c/modules/core/deployment/desc_builder.c
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/modules/core/deployment/desc_builder.c?view=diff&rev=524229&r1=524228&r2=524229
==============================================================================
--- webservices/axis2/trunk/c/modules/core/deployment/desc_builder.c (original)
+++ webservices/axis2/trunk/c/modules/core/deployment/desc_builder.c Fri Mar 30 11:46:59 2007
@@ -19,7 +19,7 @@
 #include <axis2_string.h>
 #include <axutil_class_loader.h>
 #include <axis2_utils.h>
-#include <axis2_generic_obj.h>
+#include <axutil_generic_obj.h>
 #include <axis2_raw_xml_in_out_msg_recv.h>
 
 struct axis2_desc_builder
@@ -503,7 +503,7 @@
         {
             void *v = NULL;
             axiom_attribute_t *value = NULL;
-            axis2_generic_obj_t *obj = NULL;
+            axutil_generic_obj_t *obj = NULL;
             axis2_qname_t *attr_qname = NULL;
             axis2_char_t *attr_name = NULL;
 
@@ -513,7 +513,7 @@
                 axis2_param_free(param, env);
                 return AXIS2_FAILURE;
             }
-            obj = axis2_generic_obj_create(env);
+            obj = axutil_generic_obj_create(env);
             if (!obj)
             {
                 axis2_param_free(param, env);
@@ -522,8 +522,8 @@
                 return AXIS2_FAILURE;
             }
             value = (axiom_attribute_t *) v;
-             axis2_generic_obj_set_value(obj, env, value);
-            axis2_generic_obj_set_free_func(obj, env,
+             axutil_generic_obj_set_value(obj, env, value);
+            axutil_generic_obj_set_free_func(obj, env,
                 axiom_attribute_free_void_arg);
             attr_qname = axiom_attribute_get_qname(value, env);
             attr_name = axis2_qname_to_string(attr_qname, env);

Modified: webservices/axis2/trunk/c/modules/core/transport/http/sender/axis2_http_sender_util.h
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/modules/core/transport/http/sender/axis2_http_sender_util.h?view=diff&rev=524229&r1=524228&r2=524229
==============================================================================
--- webservices/axis2/trunk/c/modules/core/transport/http/sender/axis2_http_sender_util.h (original)
+++ webservices/axis2/trunk/c/modules/core/transport/http/sender/axis2_http_sender_util.h Fri Mar 30 11:46:59 2007
@@ -30,7 +30,7 @@
 #include <axis2_property.h>
 #include <axis2_param.h>
 #include <axis2_types.h>
-#include <axis2_generic_obj.h>
+#include <axutil_generic_obj.h>
 
 #ifdef __cplusplus
 extern "C"

Modified: webservices/axis2/trunk/c/modules/core/transport/http/sender/http_sender.c
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/modules/core/transport/http/sender/http_sender.c?view=diff&rev=524229&r1=524228&r2=524229
==============================================================================
--- webservices/axis2/trunk/c/modules/core/transport/http/sender/http_sender.c (original)
+++ webservices/axis2/trunk/c/modules/core/transport/http/sender/http_sender.c Fri Mar 30 11:46:59 2007
@@ -28,7 +28,7 @@
 #include <axis2_property.h>
 #include <axis2_param.h>
 #include <axis2_types.h>
-#include <axis2_generic_obj.h>
+#include <axutil_generic_obj.h>
 #include <axis2_const.h>
 #include <axis2_util.h>
 #include <axiom_soap.h>
@@ -838,7 +838,7 @@
         transport_attrs = axis2_param_get_attributes(proxy_param, env);
         if (transport_attrs)
         {
-            axis2_generic_obj_t *obj = NULL;
+            axutil_generic_obj_t *obj = NULL;
             axiom_attribute_t *host_attr = NULL;
             axiom_attribute_t *port_attr = NULL;
             axis2_char_t *proxy_host = NULL;
@@ -850,7 +850,7 @@
             {
                 return AXIS2_FAILURE;
             }
-            host_attr = (axiom_attribute_t *) axis2_generic_obj_get_value(obj,
+            host_attr = (axiom_attribute_t *) axutil_generic_obj_get_value(obj,
 																		 env);
             if (! host_attr)
             {
@@ -866,7 +866,7 @@
 
             obj = axutil_hash_get(transport_attrs, AXIS2_PROXY_HOST_PORT,
 								 AXIS2_HASH_KEY_STRING);
-            port_attr = (axiom_attribute_t*) axis2_generic_obj_get_value(obj,
+            port_attr = (axiom_attribute_t*) axutil_generic_obj_get_value(obj,
 																		env);
             if (! port_attr)
             {

Modified: webservices/axis2/trunk/c/modules/core/transport/http/sender/libcurl/axis2_libcurl.c
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/modules/core/transport/http/sender/libcurl/axis2_libcurl.c?view=diff&rev=524229&r1=524228&r2=524229
==============================================================================
--- webservices/axis2/trunk/c/modules/core/transport/http/sender/libcurl/axis2_libcurl.c (original)
+++ webservices/axis2/trunk/c/modules/core/transport/http/sender/libcurl/axis2_libcurl.c Fri Mar 30 11:46:59 2007
@@ -11,7 +11,7 @@
 #include <axis2_property.h>
 #include <axis2_param.h>
 #include <axis2_types.h>
-#include <axis2_generic_obj.h>
+#include <axutil_generic_obj.h>
 #include <axis2_const.h>
 #include <axis2_util.h>
 #include <stdlib.h>

Modified: webservices/axis2/trunk/c/modules/core/transport/http/sender/libcurl/axis2_libcurl.h
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/modules/core/transport/http/sender/libcurl/axis2_libcurl.h?view=diff&rev=524229&r1=524228&r2=524229
==============================================================================
--- webservices/axis2/trunk/c/modules/core/transport/http/sender/libcurl/axis2_libcurl.h (original)
+++ webservices/axis2/trunk/c/modules/core/transport/http/sender/libcurl/axis2_libcurl.h Fri Mar 30 11:46:59 2007
@@ -6,7 +6,7 @@
 #include <axis2_http_sender.h>
 #include <axis2_string.h>
 #include <axis2_types.h>
-#include <axis2_generic_obj.h>
+#include <axutil_generic_obj.h>
 #include <axis2_const.h>
 #include <axis2_util.h>
 #include <axiom.h>

Modified: webservices/axis2/trunk/c/modules/core/transport/http/sender/sender_util.c
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/modules/core/transport/http/sender/sender_util.c?view=diff&rev=524229&r1=524228&r2=524229
==============================================================================
--- webservices/axis2/trunk/c/modules/core/transport/http/sender/sender_util.c (original)
+++ webservices/axis2/trunk/c/modules/core/transport/http/sender/sender_util.c Fri Mar 30 11:46:59 2007
@@ -10,7 +10,7 @@
 #include <axis2_property.h>
 #include <axis2_param.h>
 #include <axis2_types.h>
-#include <axis2_generic_obj.h>
+#include <axutil_generic_obj.h>
 
 void
 axis2_http_sender_util_add_header (const axutil_env_t *env,

Modified: webservices/axis2/trunk/c/modules/core/transport/http/server/IIS/axis2_isapi_plugin.c
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/modules/core/transport/http/server/IIS/axis2_isapi_plugin.c?view=diff&rev=524229&r1=524228&r2=524229
==============================================================================
--- webservices/axis2/trunk/c/modules/core/transport/http/server/IIS/axis2_isapi_plugin.c (original)
+++ webservices/axis2/trunk/c/modules/core/transport/http/server/IIS/axis2_isapi_plugin.c Fri Mar 30 11:46:59 2007
@@ -24,10 +24,10 @@
 
 /* Axis headers */
 #include <axutil_error_default.h>
-#include <axis2_log_default.h>
+#include <axutil_log_default.h>
 #include <axis2_thread_pool.h>
 #include <axiom_xml_reader.h>
-#include <axis2_log.h>
+#include <axutil_log.h>
 
 #include "axis2_isapi_plugin.h"
 
@@ -57,7 +57,7 @@
 static const axutil_env_t*	axutil_env = NULL;
 static axis2_char_t			repo_path[MAX_FILE_PATH] = "c:\\axis2c";
 static axis2_char_t			log_file[MAX_FILE_PATH] = "axis2.log";
-static axis2_log_levels_t	log_level = AXIS2_LOG_LEVEL_CRITICAL;
+static axutil_log_levels_t	log_level = AXIS2_LOG_LEVEL_CRITICAL;
 static axis2_char_t			redirect_word[INTERNET_MAX_URL_LENGTH] = "/axis2/mod_axis2_IIS.dll\?";
 
 /*
@@ -74,7 +74,7 @@
 /*
 Parse the given string and return the corresponding log_level
 */
-axis2_log_levels_t axis2_iis_parse_log_level(char level[]);
+axutil_log_levels_t axis2_iis_parse_log_level(char level[]);
 
 
 /*
@@ -118,7 +118,7 @@
 	These are the varibles required to initialize axis.
 	*/		
     axutil_error_t *error = NULL;
-    axis2_log_t *axis2_logger = NULL;
+    axutil_log_t *axutil_logger = NULL;
     axis2_thread_pool_t *thread_pool = NULL;
 	axis2_status_t status = FALSE;	
     // We need to init xml readers before we go into threaded env     
@@ -232,7 +232,7 @@
 
 
 
-axis2_log_levels_t axis2_iis_parse_log_level(char level[])
+axutil_log_levels_t axis2_iis_parse_log_level(char level[])
 {
     if (0 == stricmp(level, AXIS2_IIS_LOG_TRACE_VERB)) {
         return AXIS2_LOG_LEVEL_TRACE;

Modified: webservices/axis2/trunk/c/modules/core/transport/http/server/apache2/mod_axis2.c
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/modules/core/transport/http/server/apache2/mod_axis2.c?view=diff&rev=524229&r1=524228&r2=524229
==============================================================================
--- webservices/axis2/trunk/c/modules/core/transport/http/server/apache2/mod_axis2.c (original)
+++ webservices/axis2/trunk/c/modules/core/transport/http/server/apache2/mod_axis2.c Fri Mar 30 11:46:59 2007
@@ -24,16 +24,16 @@
 #include <apr_strings.h>
 #include "axis2_apache2_worker.h"
 #include <axutil_error_default.h>
-#include <axis2_log_default.h>
+#include <axutil_log_default.h>
 #include <axis2_thread_pool.h>
 #include <axiom_xml_reader.h>
 
 /* Configuration structure populated by apache2.conf */
 typedef struct axis2_config_rec
 {
-    char * axis2_log_file;
+    char * axutil_log_file;
     char * axis2_repo_path;
-    axis2_log_levels_t log_level;
+    axutil_log_levels_t log_level;
 }
 axis2_config_rec_t;
 
@@ -120,7 +120,7 @@
     server_rec *s)
 {
     axis2_config_rec_t *conf = apr_palloc(p, sizeof(*conf));
-    conf->axis2_log_file = NULL;
+    conf->axutil_log_file = NULL;
     conf->axis2_repo_path = NULL;
     conf->log_level = AXIS2_LOG_LEVEL_DEBUG;
     return conf;
@@ -160,7 +160,7 @@
 
     conf = (axis2_config_rec_t*)ap_get_module_config(
                 cmd->server->module_config, &axis2_module);
-    conf->axis2_log_file = apr_pstrdup(cmd->pool, arg);
+    conf->axutil_log_file = apr_pstrdup(cmd->pool, arg);
     return NULL;
 }
 
@@ -171,7 +171,7 @@
     const char *arg)
 {
     char *str;
-    axis2_log_levels_t level = AXIS2_LOG_LEVEL_DEBUG;
+    axutil_log_levels_t level = AXIS2_LOG_LEVEL_DEBUG;
 	axis2_config_rec_t *conf = NULL;
 	const char *err = ap_check_cmd_context(cmd, GLOBAL_ONLY);
     if (err != NULL)
@@ -271,7 +271,7 @@
     apr_status_t status;
     axutil_allocator_t *allocator = NULL;
     axutil_error_t *error = NULL;
-    axis2_log_t *axis2_logger = NULL;
+    axutil_log_t *axutil_logger = NULL;
     axis2_thread_pool_t *thread_pool = NULL;
     axis2_config_rec_t *conf = (axis2_config_rec_t*)ap_get_module_config(
                 svr_rec->module_config, &axis2_module);
@@ -321,8 +321,8 @@
                      "[Axis2] Error creating mod_axis2 error structure");
         exit(APEXIT_CHILDFATAL);
     }
-    axis2_logger = axis2_log_create(allocator, NULL, conf->axis2_log_file);
-    if (! axis2_logger)
+    axutil_logger = axutil_log_create(allocator, NULL, conf->axutil_log_file);
+    if (! axutil_logger)
     {
         ap_log_error(APLOG_MARK, APLOG_EMERG, APR_EGENERAL, svr_rec,
                      "[Axis2] Error creating mod_axis2 log structure");
@@ -336,17 +336,17 @@
         exit(APEXIT_CHILDFATAL);
     }
     axutil_env = axutil_env_create_with_error_log_thread_pool(allocator, error,
-            axis2_logger, thread_pool);
+            axutil_logger, thread_pool);
     if (! axutil_env)
     {
         ap_log_error(APLOG_MARK, APLOG_EMERG, APR_EGENERAL, svr_rec,
                      "[Axis2] Error creating mod_axis2 environment");
         exit(APEXIT_CHILDFATAL);
     }
-    if (axis2_logger)
+    if (axutil_logger)
     {
 
-        axis2_logger->level = conf->log_level;
+        axutil_logger->level = conf->log_level;
         AXIS2_LOG_INFO(axutil_env->log, "Starting log with log level %d",
                 conf->log_level);
     }

Modified: webservices/axis2/trunk/c/modules/core/transport/http/server/simple_axis2_server/http_server_main.c
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/modules/core/transport/http/server/simple_axis2_server/http_server_main.c?view=diff&rev=524229&r1=524228&r2=524229
==============================================================================
--- webservices/axis2/trunk/c/modules/core/transport/http/server/simple_axis2_server/http_server_main.c (original)
+++ webservices/axis2/trunk/c/modules/core/transport/http/server/simple_axis2_server/http_server_main.c Fri Mar 30 11:46:59 2007
@@ -21,7 +21,7 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <axutil_error_default.h>
-#include <axis2_log_default.h>
+#include <axutil_log_default.h>
 #include <axis2_thread_pool.h>
 #include <signal.h>
 #include <axis2_types.h>
@@ -53,9 +53,9 @@
     const axis2_char_t *log_file)
 {
     axutil_error_t *error = axutil_error_create(allocator);
-    axis2_log_t *log = axis2_log_create(allocator, NULL, log_file);
+    axutil_log_t *log = axutil_log_create(allocator, NULL, log_file);
 	 /* if (!log) */
-/* 		  log = axis2_log_create_default (allocator); */
+/* 		  log = axutil_log_create_default (allocator); */
     axis2_thread_pool_t *thread_pool = axis2_thread_pool_init(allocator);
     /* We need to init the parser in main thread before spawning child
      * threads
@@ -93,7 +93,7 @@
     extern char *optarg;
     extern int optopt;
     int c;
-    axis2_log_levels_t log_level = AXIS2_LOG_LEVEL_DEBUG;
+    axutil_log_levels_t log_level = AXIS2_LOG_LEVEL_DEBUG;
     const axis2_char_t *log_file = "axis2.log";
     int port = 9090;
     const axis2_char_t *repo_path = "../";

Modified: webservices/axis2/trunk/c/modules/mod_log/log_in_handler.c
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/modules/mod_log/log_in_handler.c?view=diff&rev=524229&r1=524228&r2=524229
==============================================================================
--- webservices/axis2/trunk/c/modules/mod_log/log_in_handler.c (original)
+++ webservices/axis2/trunk/c/modules/mod_log/log_in_handler.c Fri Mar 30 11:46:59 2007
@@ -32,12 +32,12 @@
 #include <axis2_property.h>
 
 axis2_status_t AXIS2_CALL
-axis2_log_in_handler_invoke(struct axis2_handler *handler, 
+axutil_log_in_handler_invoke(struct axis2_handler *handler, 
                          const axutil_env_t *env,
                          struct axis2_msg_ctx *msg_ctx);
 
 AXIS2_EXTERN axis2_handler_t* AXIS2_CALL
-axis2_log_in_handler_create(const axutil_env_t *env, 
+axutil_log_in_handler_create(const axutil_env_t *env, 
                          axis2_string_t *name) 
 {
     axis2_handler_t *handler = NULL;
@@ -54,14 +54,14 @@
     
     /* set the base struct's invoke op */
     if (handler->ops) 
-        handler->ops->invoke = axis2_log_in_handler_invoke;
+        handler->ops->invoke = axutil_log_in_handler_invoke;
 
     return handler;
 }
 
 
 axis2_status_t AXIS2_CALL
-axis2_log_in_handler_invoke(struct axis2_handler *handler, 
+axutil_log_in_handler_invoke(struct axis2_handler *handler, 
                          const axutil_env_t *env,
                          struct axis2_msg_ctx *msg_ctx)
 {

Modified: webservices/axis2/trunk/c/modules/mod_log/log_out_handler.c
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/modules/mod_log/log_out_handler.c?view=diff&rev=524229&r1=524228&r2=524229
==============================================================================
--- webservices/axis2/trunk/c/modules/mod_log/log_out_handler.c (original)
+++ webservices/axis2/trunk/c/modules/mod_log/log_out_handler.c Fri Mar 30 11:46:59 2007
@@ -32,12 +32,12 @@
 #include <axis2_property.h>
 
 axis2_status_t AXIS2_CALL
-axis2_log_out_handler_invoke(struct axis2_handler *handler, 
+axutil_log_out_handler_invoke(struct axis2_handler *handler, 
                          const axutil_env_t *env,
                          struct axis2_msg_ctx *msg_ctx);
 
 AXIS2_EXTERN axis2_handler_t* AXIS2_CALL
-axis2_log_out_handler_create(const axutil_env_t *env, 
+axutil_log_out_handler_create(const axutil_env_t *env, 
                          axis2_string_t *name) 
 {
     axis2_handler_t *handler = NULL;
@@ -54,14 +54,14 @@
     
     /* set the base struct's invoke op */
     if (handler->ops) 
-        handler->ops->invoke = axis2_log_out_handler_invoke;
+        handler->ops->invoke = axutil_log_out_handler_invoke;
 
     return handler;
 }
 
 
 axis2_status_t AXIS2_CALL
-axis2_log_out_handler_invoke(struct axis2_handler *handler, 
+axutil_log_out_handler_invoke(struct axis2_handler *handler, 
                          const axutil_env_t *env,
                          struct axis2_msg_ctx *msg_ctx)
 {

Modified: webservices/axis2/trunk/c/modules/mod_log/mod_log.c
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/modules/mod_log/mod_log.c?view=diff&rev=524229&r1=524228&r2=524229
==============================================================================
--- webservices/axis2/trunk/c/modules/mod_log/mod_log.c (original)
+++ webservices/axis2/trunk/c/modules/mod_log/mod_log.c Fri Mar 30 11:46:59 2007
@@ -105,11 +105,11 @@
         return AXIS2_FAILURE;
     }
     axutil_hash_set(module->handler_create_func_map, "LoggingInHandler", 
-        AXIS2_HASH_KEY_STRING, axis2_log_in_handler_create);
+        AXIS2_HASH_KEY_STRING, axutil_log_in_handler_create);
 
 
     axutil_hash_set(module->handler_create_func_map, "LoggingOutHandler", 
-        AXIS2_HASH_KEY_STRING, axis2_log_out_handler_create);
+        AXIS2_HASH_KEY_STRING, axutil_log_out_handler_create);
     
     return AXIS2_SUCCESS;
 }

Modified: webservices/axis2/trunk/c/modules/mod_log/mod_log.h
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/modules/mod_log/mod_log.h?view=diff&rev=524229&r1=524228&r2=524229
==============================================================================
--- webservices/axis2/trunk/c/modules/mod_log/mod_log.h (original)
+++ webservices/axis2/trunk/c/modules/mod_log/mod_log.h Fri Mar 30 11:46:59 2007
@@ -31,11 +31,11 @@
 #endif
 
 AXIS2_EXTERN axis2_handler_t* AXIS2_CALL 
-axis2_log_in_handler_create(const axutil_env_t *env, 
+axutil_log_in_handler_create(const axutil_env_t *env, 
                      axis2_string_t *name);
 
 AXIS2_EXTERN axis2_handler_t* AXIS2_CALL 
-axis2_log_out_handler_create(const axutil_env_t *env, 
+axutil_log_out_handler_create(const axutil_env_t *env, 
                        axis2_string_t *name);
     
 /** @} */

Modified: webservices/axis2/trunk/c/samples/client/dynamic_client/dynamic_client.c
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/samples/client/dynamic_client/dynamic_client.c?view=diff&rev=524229&r1=524228&r2=524229
==============================================================================
--- webservices/axis2/trunk/c/samples/client/dynamic_client/dynamic_client.c (original)
+++ webservices/axis2/trunk/c/samples/client/dynamic_client/dynamic_client.c Fri Mar 30 11:46:59 2007
@@ -18,7 +18,7 @@
 #include <axiom_element.h>
 #include <axiom_text.h>
 #include <axis2_stream.h>
-#include <axis2_log_default.h>
+#include <axutil_log_default.h>
 #include <axutil_error_default.h>
 #include <axis2_svc_client.h>
 #include <axis2_util.h>
@@ -47,14 +47,14 @@
 {
     axutil_env_t *env = NULL;
     axutil_error_t *error = NULL;
-    axis2_log_t *log = NULL;
+    axutil_log_t *log = NULL;
     axutil_allocator_t *allocator = NULL;
     axis2_char_t *wsdl_uri_str = NULL;
 
     /* set up the envioronment with allocator and log*/
     allocator = axutil_allocator_init(NULL);
     error = axutil_error_create(allocator);
-    log = axis2_log_create(allocator, NULL, "addr_echo.log");
+    log = axutil_log_create(allocator, NULL, "addr_echo.log");
     env = axutil_env_create_with_error_log(allocator, error, log);
     env->log->level = AXIS2_LOG_LEVEL_TRACE;
     axutil_error_init();

Modified: webservices/axis2/trunk/c/samples/client/dynamic_client/test.c
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/samples/client/dynamic_client/test.c?view=diff&rev=524229&r1=524228&r2=524229
==============================================================================
--- webservices/axis2/trunk/c/samples/client/dynamic_client/test.c (original)
+++ webservices/axis2/trunk/c/samples/client/dynamic_client/test.c Fri Mar 30 11:46:59 2007
@@ -18,7 +18,7 @@
 #include <axiom_element.h>
 #include <axiom_text.h>
 #include <axis2_stream.h>
-#include <axis2_log_default.h>
+#include <axutil_log_default.h>
 #include <axutil_error_default.h>
 #include <axis2_svc_client.h>
 #include <stdlib.h>
@@ -31,13 +31,13 @@
 {
     axutil_env_t *env = NULL;
     axutil_error_t *error = NULL;
-    axis2_log_t *log = NULL;
+    axutil_log_t *log = NULL;
     axutil_allocator_t *allocator = NULL;
 
     /* set up the envioronment with allocator and log*/
     allocator = axutil_allocator_init(NULL);
     error = axutil_error_create(allocator);
-    log = axis2_log_create(allocator, NULL, "addr_echo.log");
+    log = axutil_log_create(allocator, NULL, "addr_echo.log");
     env = axutil_env_create_with_error_log(allocator, error, log);
     env->log->level = AXIS2_LOG_LEVEL_TRACE;
     axutil_error_init();

Modified: webservices/axis2/trunk/c/samples/server/Calculator/calc.h
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/samples/server/Calculator/calc.h?view=diff&rev=524229&r1=524228&r2=524229
==============================================================================
--- webservices/axis2/trunk/c/samples/server/Calculator/calc.h (original)
+++ webservices/axis2/trunk/c/samples/server/Calculator/calc.h Fri Mar 30 11:46:59 2007
@@ -19,7 +19,7 @@
 
 
 #include <axis2_svc_skeleton.h>
-#include <axis2_log_default.h>
+#include <axutil_log_default.h>
 #include <axutil_error_default.h>
 #include <axiom_text.h>
 #include <axiom_node.h>

Modified: webservices/axis2/trunk/c/samples/server/echo/echo.h
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/samples/server/echo/echo.h?view=diff&rev=524229&r1=524228&r2=524229
==============================================================================
--- webservices/axis2/trunk/c/samples/server/echo/echo.h (original)
+++ webservices/axis2/trunk/c/samples/server/echo/echo.h Fri Mar 30 11:46:59 2007
@@ -19,7 +19,7 @@
 
 
 #include <axis2_svc_skeleton.h>
-#include <axis2_log_default.h>
+#include <axutil_log_default.h>
 #include <axutil_error_default.h>
 #include <axiom_text.h>
 #include <axiom_node.h>

Modified: webservices/axis2/trunk/c/samples/server/math/math.h
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/samples/server/math/math.h?view=diff&rev=524229&r1=524228&r2=524229
==============================================================================
--- webservices/axis2/trunk/c/samples/server/math/math.h (original)
+++ webservices/axis2/trunk/c/samples/server/math/math.h Fri Mar 30 11:46:59 2007
@@ -19,7 +19,7 @@
 
 
 #include <axis2_svc_skeleton.h>
-#include <axis2_log_default.h>
+#include <axutil_log_default.h>
 #include <axutil_error_default.h>
 #include <axiom_text.h>
 #include <axiom_node.h>

Modified: webservices/axis2/trunk/c/samples/server/mtom/mtom.h
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/samples/server/mtom/mtom.h?view=diff&rev=524229&r1=524228&r2=524229
==============================================================================
--- webservices/axis2/trunk/c/samples/server/mtom/mtom.h (original)
+++ webservices/axis2/trunk/c/samples/server/mtom/mtom.h Fri Mar 30 11:46:59 2007
@@ -19,7 +19,7 @@
 
 
 #include <axis2_svc_skeleton.h>
-#include <axis2_log_default.h>
+#include <axutil_log_default.h>
 #include <axutil_error_default.h>
 #include <axiom_text.h>
 #include <axiom_node.h>

Modified: webservices/axis2/trunk/c/samples/server/notify/notify.h
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/samples/server/notify/notify.h?view=diff&rev=524229&r1=524228&r2=524229
==============================================================================
--- webservices/axis2/trunk/c/samples/server/notify/notify.h (original)
+++ webservices/axis2/trunk/c/samples/server/notify/notify.h Fri Mar 30 11:46:59 2007
@@ -19,7 +19,7 @@
 
 
 #include <axis2_svc_skeleton.h>
-#include <axis2_log_default.h>
+#include <axutil_log_default.h>
 #include <axutil_error_default.h>
 #include <axiom_text.h>
 #include <axiom_node.h>

Modified: webservices/axis2/trunk/c/samples/server/sg_math/add.h
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/samples/server/sg_math/add.h?view=diff&rev=524229&r1=524228&r2=524229
==============================================================================
--- webservices/axis2/trunk/c/samples/server/sg_math/add.h (original)
+++ webservices/axis2/trunk/c/samples/server/sg_math/add.h Fri Mar 30 11:46:59 2007
@@ -19,7 +19,7 @@
 
 
 #include <axis2_svc_skeleton.h>
-#include <axis2_log_default.h>
+#include <axutil_log_default.h>
 #include <axutil_error_default.h>
 #include <axiom_text.h>
 #include <axiom_node.h>

Modified: webservices/axis2/trunk/c/samples/server/sg_math/div.h
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/samples/server/sg_math/div.h?view=diff&rev=524229&r1=524228&r2=524229
==============================================================================
--- webservices/axis2/trunk/c/samples/server/sg_math/div.h (original)
+++ webservices/axis2/trunk/c/samples/server/sg_math/div.h Fri Mar 30 11:46:59 2007
@@ -19,7 +19,7 @@
 
 
 #include <axis2_svc_skeleton.h>
-#include <axis2_log_default.h>
+#include <axutil_log_default.h>
 #include <axutil_error_default.h>
 #include <axiom_text.h>
 #include <axiom_node.h>

Modified: webservices/axis2/trunk/c/samples/server/sg_math/mul.h
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/samples/server/sg_math/mul.h?view=diff&rev=524229&r1=524228&r2=524229
==============================================================================
--- webservices/axis2/trunk/c/samples/server/sg_math/mul.h (original)
+++ webservices/axis2/trunk/c/samples/server/sg_math/mul.h Fri Mar 30 11:46:59 2007
@@ -19,7 +19,7 @@
 
 
 #include <axis2_svc_skeleton.h>
-#include <axis2_log_default.h>
+#include <axutil_log_default.h>
 #include <axutil_error_default.h>
 #include <axiom_text.h>
 #include <axiom_node.h>

Modified: webservices/axis2/trunk/c/samples/server/sg_math/sub.h
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/samples/server/sg_math/sub.h?view=diff&rev=524229&r1=524228&r2=524229
==============================================================================
--- webservices/axis2/trunk/c/samples/server/sg_math/sub.h (original)
+++ webservices/axis2/trunk/c/samples/server/sg_math/sub.h Fri Mar 30 11:46:59 2007
@@ -19,7 +19,7 @@
 
 
 #include <axis2_svc_skeleton.h>
-#include <axis2_log_default.h>
+#include <axutil_log_default.h>
 #include <axutil_error_default.h>
 #include <axiom_text.h>
 #include <axiom_node.h>

Modified: webservices/axis2/trunk/c/savan/samples/server/listener/listener.h
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/savan/samples/server/listener/listener.h?view=diff&rev=524229&r1=524228&r2=524229
==============================================================================
--- webservices/axis2/trunk/c/savan/samples/server/listener/listener.h (original)
+++ webservices/axis2/trunk/c/savan/samples/server/listener/listener.h Fri Mar 30 11:46:59 2007
@@ -18,7 +18,7 @@
 
 
 #include <axis2_svc_skeleton.h>
-#include <axis2_log_default.h>
+#include <axutil_log_default.h>
 #include <axutil_error_default.h>
 #include <axiom_text.h>
 #include <axiom_node.h>

Modified: webservices/axis2/trunk/c/savan/samples/server/publisher/publisher.h
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/savan/samples/server/publisher/publisher.h?view=diff&rev=524229&r1=524228&r2=524229
==============================================================================
--- webservices/axis2/trunk/c/savan/samples/server/publisher/publisher.h (original)
+++ webservices/axis2/trunk/c/savan/samples/server/publisher/publisher.h Fri Mar 30 11:46:59 2007
@@ -18,7 +18,7 @@
 
 
 #include <axis2_svc_skeleton.h>
-#include <axis2_log_default.h>
+#include <axutil_log_default.h>
 #include <axutil_error_default.h>
 #include <axiom_text.h>
 #include <axiom_node.h>

Modified: webservices/axis2/trunk/c/test/core/deployment/test_deployment.c
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/test/core/deployment/test_deployment.c?view=diff&rev=524229&r1=524228&r2=524229
==============================================================================
--- webservices/axis2/trunk/c/test/core/deployment/test_deployment.c (original)
+++ webservices/axis2/trunk/c/test/core/deployment/test_deployment.c Fri Mar 30 11:46:59 2007
@@ -26,7 +26,7 @@
 #include <axutil_allocator.h>
 #include <axutil_class_loader.h>
 #include <axutil_error_default.h>
-#include <axis2_log_default.h>
+#include <axutil_log_default.h>
 #include <axis2_transport_sender.h>
 #include <axis2_transport_receiver.h>
 #include <axis2_core_utils.h>
@@ -329,11 +329,11 @@
 {
     axutil_allocator_t *allocator = NULL;
     axutil_error_t *error = NULL;
-    axis2_log_t *log = NULL;
+    axutil_log_t *log = NULL;
 
     allocator = axutil_allocator_init(NULL);
     error = axutil_error_create(allocator);
-    log = axis2_log_create(allocator, NULL, "test_deployment.log");
+    log = axutil_log_create(allocator, NULL, "test_deployment.log");
     env = axutil_env_create_with_error_log(allocator, error, log);
     env->log->level = AXIS2_LOG_LEVEL_INFO;
     /*axis2_test_transport_receiver_load();

Modified: webservices/axis2/trunk/c/tools/codegen/samples/server/calculator/axis2_skel_calculator.h
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/tools/codegen/samples/server/calculator/axis2_skel_calculator.h?view=diff&rev=524229&r1=524228&r2=524229
==============================================================================
--- webservices/axis2/trunk/c/tools/codegen/samples/server/calculator/axis2_skel_calculator.h (original)
+++ webservices/axis2/trunk/c/tools/codegen/samples/server/calculator/axis2_skel_calculator.h Fri Mar 30 11:46:59 2007
@@ -10,7 +10,7 @@
 
 
 #include <axis2_svc_skeleton.h>
-#include <axis2_log_default.h>
+#include <axutil_log_default.h>
 #include <axutil_error_default.h>
 #include <axiom_text.h>
 #include <axiom_node.h>

Modified: webservices/axis2/trunk/c/tools/codegen/samples/server/interop_test_svc/axis2_skel_interop_test_port_type_doc_service.h
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/tools/codegen/samples/server/interop_test_svc/axis2_skel_interop_test_port_type_doc_service.h?view=diff&rev=524229&r1=524228&r2=524229
==============================================================================
--- webservices/axis2/trunk/c/tools/codegen/samples/server/interop_test_svc/axis2_skel_interop_test_port_type_doc_service.h (original)
+++ webservices/axis2/trunk/c/tools/codegen/samples/server/interop_test_svc/axis2_skel_interop_test_port_type_doc_service.h Fri Mar 30 11:46:59 2007
@@ -10,7 +10,7 @@
 
 
 #include <axis2_svc_skeleton.h>
-#include <axis2_log_default.h>
+#include <axutil_log_default.h>
 #include <axutil_error_default.h>
 #include <axiom_text.h>
 #include <axiom_node.h>

Modified: webservices/axis2/trunk/c/tools/tcpmon/src/tcpmon.c
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/tools/tcpmon/src/tcpmon.c?view=diff&rev=524229&r1=524228&r2=524229
==============================================================================
--- webservices/axis2/trunk/c/tools/tcpmon/src/tcpmon.c (original)
+++ webservices/axis2/trunk/c/tools/tcpmon/src/tcpmon.c Fri Mar 30 11:46:59 2007
@@ -17,7 +17,7 @@
 
 #include <axis2_utils.h>
 #include <axutil_error_default.h>
-#include <axis2_log_default.h>
+#include <axutil_log_default.h>
 #include <axis2_thread_pool.h>
 #include <tcpmon_session.h>
 #include <tcpmon_entry.h>
@@ -38,7 +38,7 @@
 		axutil_env_t* env = NULL;
 		axutil_allocator_t* allocator = NULL;
 		axutil_error_t *error = NULL;
-		axis2_log_t *log = NULL;
+		axutil_log_t *log = NULL;
 		axis2_thread_pool_t *thread_pool = NULL;
 		tcpmon_session_t* session = NULL;
 		int c;
@@ -51,7 +51,7 @@
 		allocator = axutil_allocator_init(NULL);
 
 		error = axutil_error_create(allocator);
-		log = axis2_log_create(allocator, NULL, "axis2_tcpmon.log");
+		log = axutil_log_create(allocator, NULL, "axis2_tcpmon.log");
 		thread_pool = axis2_thread_pool_init(allocator);
 
 		env = axutil_env_create_with_error_log_thread_pool(allocator, error, log,

Modified: webservices/axis2/trunk/c/util/include/axutil_env.h
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/util/include/axutil_env.h?view=diff&rev=524229&r1=524228&r2=524229
==============================================================================
--- webservices/axis2/trunk/c/util/include/axutil_env.h (original)
+++ webservices/axis2/trunk/c/util/include/axutil_env.h Fri Mar 30 11:46:59 2007
@@ -26,7 +26,7 @@
 
 #include <axutil_allocator.h>
 #include <axutil_error.h>
-#include <axis2_log.h>
+#include <axutil_log.h>
 #include <axis2_thread_pool.h>
 
 #ifdef __cplusplus
@@ -63,7 +63,7 @@
         /** Error handling */
         axutil_error_t *error;
         /** Logging routines */
-        axis2_log_t *log;
+        axutil_log_t *log;
         /** This flag indicate whether logging is enabled or not */
         axis2_bool_t log_enabled;
         /** Thread pooling routines */
@@ -80,7 +80,7 @@
     */
     AXIS2_EXTERN axutil_env_t * AXIS2_CALL 
     axutil_env_create_all(const axis2_char_t *log_file,
-        const axis2_log_levels_t log_level);
+        const axutil_log_levels_t log_level);
 
     /**
      * Creates an environment struct. Users of axis2 should not use this function
@@ -113,7 +113,7 @@
     AXIS2_EXTERN axutil_env_t * AXIS2_CALL 
     axutil_env_create_with_error_log(axutil_allocator_t *allocator, 
         axutil_error_t *error, 
-        axis2_log_t *log);
+        axutil_log_t *log);
 
     /**
     * Creates an environment struct
@@ -127,7 +127,7 @@
     AXIS2_EXTERN axutil_env_t * AXIS2_CALL 
     axutil_env_create_with_error_log_thread_pool(axutil_allocator_t *allocator, 
         axutil_error_t *error, 
-        axis2_log_t *log, 
+        axutil_log_t *log, 
         axis2_thread_pool_t *pool);
 
     /**

Copied: webservices/axis2/trunk/c/util/include/axutil_generic_obj.h (from r524208, webservices/axis2/trunk/c/util/include/axis2_generic_obj.h)
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/util/include/axutil_generic_obj.h?view=diff&rev=524229&p1=webservices/axis2/trunk/c/util/include/axis2_generic_obj.h&r1=524208&p2=webservices/axis2/trunk/c/util/include/axutil_generic_obj.h&r2=524229
==============================================================================
--- webservices/axis2/trunk/c/util/include/axis2_generic_obj.h (original)
+++ webservices/axis2/trunk/c/util/include/axutil_generic_obj.h Fri Mar 30 11:46:59 2007
@@ -15,8 +15,8 @@
  * limitations under the License.
  */
 
-#ifndef AXIS2_GENERIC_OBJ_H
-#define AXIS2_GENERIC_OBJ_H
+#ifndef AXUTIL_GENERIC_OBJ_H
+#define AXUTIL_GENERIC_OBJ_H
 
 #include <axis2_utils_defines.h>
 #include <axutil_error.h>
@@ -29,10 +29,10 @@
 {
 #endif
 
-    typedef struct axis2_generic_obj axis2_generic_obj_t;
+    typedef struct axutil_generic_obj axutil_generic_obj_t;
 
     /**
-     * @defgroup axis2_generic_obj generic object
+     * @defgroup axutil_generic_obj generic object
      * @ingroup axis2_util
      * @{
      */
@@ -41,34 +41,34 @@
      * create new generic_obj
      * @return generic_obj newly created generic_obj
      */
-    AXIS2_EXTERN axis2_generic_obj_t * AXIS2_CALL
-    axis2_generic_obj_create(const axutil_env_t *env);
+    AXIS2_EXTERN axutil_generic_obj_t * AXIS2_CALL
+    axutil_generic_obj_create(const axutil_env_t *env);
 
     AXIS2_EXTERN void AXIS2_CALL
-    axis2_generic_obj_free(axis2_generic_obj_t *generic_obj,
+    axutil_generic_obj_free(axutil_generic_obj_t *generic_obj,
         const axutil_env_t *env);
 
     AXIS2_EXTERN axis2_status_t AXIS2_CALL
-    axis2_generic_obj_set_free_func(axis2_generic_obj_t *generic_obj,
+    axutil_generic_obj_set_free_func(axutil_generic_obj_t *generic_obj,
         const axutil_env_t *env,
         AXIS2_FREE_VOID_ARG free_func);
 
     AXIS2_EXTERN axis2_status_t AXIS2_CALL
-    axis2_generic_obj_set_value(axis2_generic_obj_t *generic_obj,
+    axutil_generic_obj_set_value(axutil_generic_obj_t *generic_obj,
         const axutil_env_t *env,
         void *value);
 
     AXIS2_EXTERN void * AXIS2_CALL
-    axis2_generic_obj_get_value(axis2_generic_obj_t *generic_obj,
+    axutil_generic_obj_get_value(axutil_generic_obj_t *generic_obj,
         const axutil_env_t *env);
 
     AXIS2_EXTERN axis2_status_t AXIS2_CALL
-    axis2_generic_obj_set_type(axis2_generic_obj_t *generic_obj,
+    axutil_generic_obj_set_type(axutil_generic_obj_t *generic_obj,
         const axutil_env_t *env,
         int type);
 
     AXIS2_EXTERN int AXIS2_CALL
-    axis2_generic_obj_get_type(axis2_generic_obj_t *generic_obj,
+    axutil_generic_obj_get_type(axutil_generic_obj_t *generic_obj,
         const axutil_env_t *env);
 
 

Copied: webservices/axis2/trunk/c/util/include/axutil_linked_list.h (from r524188, webservices/axis2/trunk/c/util/include/axis2_linked_list.h)
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/util/include/axutil_linked_list.h?view=diff&rev=524229&p1=webservices/axis2/trunk/c/util/include/axis2_linked_list.h&r1=524188&p2=webservices/axis2/trunk/c/util/include/axutil_linked_list.h&r2=524229
==============================================================================
--- webservices/axis2/trunk/c/util/include/axis2_linked_list.h (original)
+++ webservices/axis2/trunk/c/util/include/axutil_linked_list.h Fri Mar 30 11:46:59 2007
@@ -15,11 +15,11 @@
  * limitations under the License.
  */
 
-#ifndef AXIS2_LINKED_LIST_H
-#define AXIS2_LINKED_LIST_H
+#ifndef AXUTIL_LINKED_LIST_H
+#define AXUTIL_LINKED_LIST_H
 
 /**
- * @file axis2_linked_list.h
+ * @file axutil_linked_list.h
  * @brief Axis2 linked_list interface
  */
 
@@ -31,10 +31,10 @@
 {
 #endif
 
-    typedef struct axis2_linked_list axis2_linked_list_t;
+    typedef struct axutil_linked_list axutil_linked_list_t;
 
     /**
-     * @defgroup axis2_linked_list linked list
+     * @defgroup axutil_linked_list linked list
      * @ingroup axis2_util
      * @{
      */
@@ -59,11 +59,11 @@
     /**
     * Create an empty linked list.
     */
-    AXIS2_EXTERN axis2_linked_list_t* AXIS2_CALL 
-    axis2_linked_list_create(const axutil_env_t *env);
+    AXIS2_EXTERN axutil_linked_list_t* AXIS2_CALL 
+    axutil_linked_list_create(const axutil_env_t *env);
 
     AXIS2_EXTERN void AXIS2_CALL
-    axis2_linked_list_free(axis2_linked_list_t *linked_list,
+    axutil_linked_list_free(axutil_linked_list_t *linked_list,
         const axutil_env_t *env);
 
     /**
@@ -79,7 +79,7 @@
     * @return the entry at position n
     */
     AXIS2_EXTERN entry_t * AXIS2_CALL
-    axis2_linked_list_get_entry(axis2_linked_list_t *linked_list,
+    axutil_linked_list_get_entry(axutil_linked_list_t *linked_list,
         const axutil_env_t *env,
         int n);
 
@@ -90,7 +90,7 @@
      * @param e the entry to remove
      */
     AXIS2_EXTERN axis2_status_t AXIS2_CALL
-    axis2_linked_list_remove_entry(axis2_linked_list_t *linked_list,
+    axutil_linked_list_remove_entry(axutil_linked_list_t *linked_list,
         const axutil_env_t *env,
         entry_t *e);
 
@@ -101,7 +101,7 @@
      * @param index the index to check
      */
     AXIS2_EXTERN axis2_bool_t AXIS2_CALL
-    axis2_linked_list_check_bounds_inclusive(axis2_linked_list_t *linked_list,
+    axutil_linked_list_check_bounds_inclusive(axutil_linked_list_t *linked_list,
         const axutil_env_t *env,
         int index);
 
@@ -111,7 +111,7 @@
     * @param index the index to check
     */
     AXIS2_EXTERN axis2_bool_t AXIS2_CALL
-    axis2_linked_list_check_bounds_exclusive(axis2_linked_list_t *linked_list,
+    axutil_linked_list_check_bounds_exclusive(axutil_linked_list_t *linked_list,
         const axutil_env_t *env,
         int index);
 
@@ -121,7 +121,7 @@
     * @return the first list element
     */
     AXIS2_EXTERN void * AXIS2_CALL
-    axis2_linked_list_get_first(axis2_linked_list_t *linked_list,
+    axutil_linked_list_get_first(axutil_linked_list_t *linked_list,
         const axutil_env_t *env);
 
     /**
@@ -130,7 +130,7 @@
     * @return the last list element
     */
     AXIS2_EXTERN void * AXIS2_CALL
-    axis2_linked_list_get_last(axis2_linked_list_t *linked_list,
+    axutil_linked_list_get_last(axutil_linked_list_t *linked_list,
         const axutil_env_t *env);
 
     /**
@@ -139,7 +139,7 @@
     * @return the former first element in the list
     */
     AXIS2_EXTERN void * AXIS2_CALL
-    axis2_linked_list_remove_first(axis2_linked_list_t *linked_list,
+    axutil_linked_list_remove_first(axutil_linked_list_t *linked_list,
         const axutil_env_t *env);
 
     /**
@@ -148,7 +148,7 @@
     * @return the former last element in the list
     */
     AXIS2_EXTERN void * AXIS2_CALL
-    axis2_linked_list_remove_last(axis2_linked_list_t *linked_list,
+    axutil_linked_list_remove_last(axutil_linked_list_t *linked_list,
         const axutil_env_t *env);
 
     /**
@@ -157,7 +157,7 @@
     * @param o the element to insert
     */
     AXIS2_EXTERN axis2_status_t AXIS2_CALL
-    axis2_linked_list_add_first(axis2_linked_list_t *linked_list,
+    axutil_linked_list_add_first(axutil_linked_list_t *linked_list,
         const axutil_env_t *env,
         void *o);
 
@@ -167,7 +167,7 @@
     * @param o the element to insert
     */
     AXIS2_EXTERN axis2_status_t AXIS2_CALL
-    axis2_linked_list_add_last(axis2_linked_list_t *linked_list,
+    axutil_linked_list_add_last(axutil_linked_list_t *linked_list,
         const axutil_env_t *env,
         void *o);
 
@@ -179,7 +179,7 @@
     * @return true if it is found
     */
     AXIS2_EXTERN axis2_bool_t AXIS2_CALL
-    axis2_linked_list_contains(axis2_linked_list_t *linked_list,
+    axutil_linked_list_contains(axutil_linked_list_t *linked_list,
         const axutil_env_t *env,
         void *o);
 
@@ -189,7 +189,7 @@
     * @return the list size
     */
     AXIS2_EXTERN int AXIS2_CALL
-    axis2_linked_list_size(axis2_linked_list_t *linked_list,
+    axutil_linked_list_size(axutil_linked_list_t *linked_list,
         const axutil_env_t *env);
 
     /**
@@ -199,7 +199,7 @@
     * @return true, as it always succeeds
     */
     AXIS2_EXTERN axis2_bool_t AXIS2_CALL
-    axis2_linked_list_add(axis2_linked_list_t *linked_list,
+    axutil_linked_list_add(axutil_linked_list_t *linked_list,
         const axutil_env_t *env,
         void *o);
 
@@ -211,7 +211,7 @@
     * @return true if an instance of the object was removed
     */
     AXIS2_EXTERN axis2_bool_t AXIS2_CALL
-    axis2_linked_list_remove(axis2_linked_list_t *linked_list,
+    axutil_linked_list_remove(axutil_linked_list_t *linked_list,
         const axutil_env_t *env,
         void *o);
 
@@ -219,7 +219,7 @@
     * Remove all elements from this list.
     */
     AXIS2_EXTERN axis2_status_t AXIS2_CALL
-    axis2_linked_list_clear(axis2_linked_list_t *linked_list,
+    axutil_linked_list_clear(axutil_linked_list_t *linked_list,
         const axutil_env_t *env);
 
     /**
@@ -229,7 +229,7 @@
     * @return the element at index
     */
     AXIS2_EXTERN void * AXIS2_CALL
-    axis2_linked_list_get(axis2_linked_list_t *linked_list,
+    axutil_linked_list_get(axutil_linked_list_t *linked_list,
         const axutil_env_t *env,
         int index);
 
@@ -241,7 +241,7 @@
     * @return the prior element
     */
     AXIS2_EXTERN void * AXIS2_CALL
-    axis2_linked_list_set(axis2_linked_list_t *linked_list,
+    axutil_linked_list_set(axutil_linked_list_t *linked_list,
         const axutil_env_t *env,
         int index, 
         void *o);
@@ -253,7 +253,7 @@
     * @param o the element to insert
     */
     AXIS2_EXTERN axis2_status_t AXIS2_CALL
-    axis2_linked_list_add_at_index(axis2_linked_list_t *linked_list,
+    axutil_linked_list_add_at_index(axutil_linked_list_t *linked_list,
         const axutil_env_t *env,
         int index,
         void *o);
@@ -265,7 +265,7 @@
     * @return the removed element
     */
     AXIS2_EXTERN void * AXIS2_CALL
-    axis2_linked_list_remove_at_index(axis2_linked_list_t *linked_list,
+    axutil_linked_list_remove_at_index(axutil_linked_list_t *linked_list,
         const axutil_env_t *env,
         int index);
 
@@ -276,7 +276,7 @@
     * @return its position, or -1 if not found
     */
     AXIS2_EXTERN int AXIS2_CALL
-    axis2_linked_list_index_of(axis2_linked_list_t *linked_list,
+    axutil_linked_list_index_of(axutil_linked_list_t *linked_list,
         const axutil_env_t *env,
         void *o);
 
@@ -287,7 +287,7 @@
     * @return its position, or -1 if not found
     */
     AXIS2_EXTERN int AXIS2_CALL
-    axis2_linked_list_last_index_of(axis2_linked_list_t *linked_list,
+    axutil_linked_list_last_index_of(axutil_linked_list_t *linked_list,
         const axutil_env_t *env,
         void *o);
 
@@ -297,7 +297,7 @@
     * @return an array containing the list elements
     */
     AXIS2_EXTERN void ** AXIS2_CALL
-    axis2_linked_list_to_array(axis2_linked_list_t *linked_list,
+    axutil_linked_list_to_array(axutil_linked_list_t *linked_list,
         const axutil_env_t *env);
 
 #ifdef __cplusplus

Copied: webservices/axis2/trunk/c/util/include/axutil_log.h (from r524179, webservices/axis2/trunk/c/util/include/axis2_log.h)
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/util/include/axutil_log.h?view=diff&rev=524229&p1=webservices/axis2/trunk/c/util/include/axis2_log.h&r1=524179&p2=webservices/axis2/trunk/c/util/include/axutil_log.h&r2=524229
==============================================================================
--- webservices/axis2/trunk/c/util/include/axis2_log_default.h (original)
+++ webservices/axis2/trunk/c/util/include/axutil_log_default.h Fri Mar 30 11:46:59 2007
@@ -15,12 +15,12 @@
  * limitations under the License.
  */
 
-#ifndef AXIS2_LOG_DEFAULT_H
-#define AXIS2_LOG_DEFAULT_H
+#ifndef AXUTIL_LOG_DEFAULT_H
+#define AXUTIL_LOG_DEFAULT_H
 
 #include <stdlib.h>
 #include <stdarg.h>
-#include <axis2_log.h>
+#include <axutil_log.h>
 #include <axutil_allocator.h>
 
 
@@ -31,7 +31,7 @@
 
 
 /**
- * @defgroup axis2_log Log
+ * @defgroup axutil_log Log
  * @ingroup axis2_util 
  * @{
  */
@@ -44,12 +44,12 @@
     * @param allocator allocator to be used. Mandatory, cannot be NULL    
     * @return pointer to the newly created log struct 
     */
-    AXIS2_EXTERN axis2_log_t * AXIS2_CALL axis2_log_create (axutil_allocator_t * allocator,
-                     axis2_log_ops_t * ops, const axis2_char_t * stream_name);
-    AXIS2_EXTERN axis2_char_t *AXIS2_CALL  axis2_log_impl_get_time_str(void);
+    AXIS2_EXTERN axutil_log_t * AXIS2_CALL axutil_log_create (axutil_allocator_t * allocator,
+                     axutil_log_ops_t * ops, const axis2_char_t * stream_name);
+    AXIS2_EXTERN axis2_char_t *AXIS2_CALL  axutil_log_impl_get_time_str(void);
     
-    AXIS2_EXTERN axis2_log_t * AXIS2_CALL 
-    axis2_log_create_default (axutil_allocator_t *allocator);
+    AXIS2_EXTERN axutil_log_t * AXIS2_CALL 
+    axutil_log_create_default (axutil_allocator_t *allocator);
 
 /** @} */
     

Modified: webservices/axis2/trunk/c/util/include/platforms/unix/axis2_unix.h
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/util/include/platforms/unix/axis2_unix.h?view=diff&rev=524229&r1=524228&r2=524229
==============================================================================
--- webservices/axis2/trunk/c/util/include/platforms/unix/axis2_unix.h (original)
+++ webservices/axis2/trunk/c/util/include/platforms/unix/axis2_unix.h Fri Mar 30 11:46:59 2007
@@ -50,7 +50,7 @@
 #define AXIS2_PLATFORM_CHANNEL_PATH        "libhttp_channel.so"
 #define AXIS2_PLATFORM_SSLCHANNEL_PATH     "Unknown"
 
-#define AXIS2_PLATFORM_LOG_PATH            "/usr/local/axis2/log/axis2_log"
+#define AXIS2_PLATFORM_LOG_PATH            "/usr/local/axis2/log/axutil_log"
 #define AXIS2_PLATFORM_CLIENTLOG_PATH      "/usr/local/axis2/log/axis2_client_log"
 #define AXIS2_PLATFORM_CONFIG_PATH         "/etc/axiscpp.conf"
 #define AXIS2_PLATFORM_SECUREINFO          ""

Modified: webservices/axis2/trunk/c/util/include/platforms/windows/axis2_windows.h
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/util/include/platforms/windows/axis2_windows.h?view=diff&rev=524229&r1=524228&r2=524229
==============================================================================
--- webservices/axis2/trunk/c/util/include/platforms/windows/axis2_windows.h (original)
+++ webservices/axis2/trunk/c/util/include/platforms/windows/axis2_windows.h Fri Mar 30 11:46:59 2007
@@ -74,7 +74,7 @@
 #define AXIS2_PLATFORM_CHANNEL_PATH        "http_channel.dll"
 #define AXIS2_PLATFORM_SSLCHANNEL_PATH     "Unknown"
 
-#define AXIS2_PLATFORM_LOG_PATH            ""  /*/usr/local/axis2/log/axis2_log*/
+#define AXIS2_PLATFORM_LOG_PATH            ""  /*/usr/local/axis2/log/axutil_log*/
 #define AXIS2_PLATFORM_CLIENTLOG_PATH      "" /* /usr/local/axis2/log/axis2_client_log*/
 #define AXIS2_PLATFORM_CONFIG_PATH         "" /* /etc/axiscpp.conf */
 #define AXIS2_PLATFORM_SECUREINFO          "" 

Modified: webservices/axis2/trunk/c/util/src/env.c
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/util/src/env.c?view=diff&rev=524229&r1=524228&r2=524229
==============================================================================
--- webservices/axis2/trunk/c/util/src/env.c (original)
+++ webservices/axis2/trunk/c/util/src/env.c Fri Mar 30 11:46:59 2007
@@ -19,16 +19,16 @@
 #include <string.h>
 #include <axutil_env.h>
 #include <axutil_error_default.h>
-#include <axis2_log_default.h>
+#include <axutil_log_default.h>
 #include <axis2_string.h>
 
 AXIS2_EXTERN axutil_env_t * AXIS2_CALL 
 axutil_env_create_all(const axis2_char_t *log_file,
-    const axis2_log_levels_t log_level)
+    const axutil_log_levels_t log_level)
 {
     axutil_env_t *env = NULL;
     axutil_error_t *error = NULL;
-    axis2_log_t *log = NULL;
+    axutil_log_t *log = NULL;
     axutil_allocator_t *allocator = NULL;
     axis2_thread_pool_t *thread_pool = NULL;
 
@@ -36,12 +36,12 @@
     error = axutil_error_create(allocator);
 
     if (log_file)
-        log = axis2_log_create(allocator, NULL, log_file);
+        log = axutil_log_create(allocator, NULL, log_file);
     else
-        log = axis2_log_create_default(allocator);
+        log = axutil_log_create_default(allocator);
 
     if (!log)
-        log = axis2_log_create_default(allocator);
+        log = axutil_log_create_default(allocator);
 
     thread_pool = axis2_thread_pool_init(allocator);
     env = axutil_env_create_with_error_log_thread_pool(allocator, error, log, thread_pool);
@@ -95,7 +95,7 @@
 axutil_env_create(axutil_allocator_t *allocator)
 {
     axutil_env_t *environment;
-    axis2_log_t *log = NULL;
+    axutil_log_t *log = NULL;
 
     if (! allocator)
         return NULL;
@@ -106,7 +106,7 @@
     if (! environment)
         return NULL;
 
-    log = axis2_log_create_default(allocator);
+    log = axutil_log_create_default(allocator);
 
     environment->allocator = allocator;
 
@@ -130,7 +130,7 @@
 AXIS2_EXTERN axutil_env_t * AXIS2_CALL
 axutil_env_create_with_error_log(axutil_allocator_t *allocator, 
     axutil_error_t *error, 
-    axis2_log_t *log)
+    axutil_log_t *log)
 {
     axutil_env_t *environment;
     if (! allocator)
@@ -165,7 +165,7 @@
 AXIS2_EXTERN axutil_env_t * AXIS2_CALL
 axutil_env_create_with_error_log_thread_pool(axutil_allocator_t *allocator, 
     axutil_error_t *error, 
-    axis2_log_t *log, 
+    axutil_log_t *log, 
     axis2_thread_pool_t *pool)
 {
     axutil_env_t *environment;

Modified: webservices/axis2/trunk/c/util/src/generic_obj.c
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/util/src/generic_obj.c?view=diff&rev=524229&r1=524228&r2=524229
==============================================================================
--- webservices/axis2/trunk/c/util/src/generic_obj.c (original)
+++ webservices/axis2/trunk/c/util/src/generic_obj.c Fri Mar 30 11:46:59 2007
@@ -15,23 +15,23 @@
  * limitations under the License.
  */
 
-#include <axis2_generic_obj.h>
+#include <axutil_generic_obj.h>
 
-struct axis2_generic_obj
+struct axutil_generic_obj
 {
     AXIS2_FREE_VOID_ARG free_func;
     int type;
     void *value;
 };
 
-AXIS2_EXTERN axis2_generic_obj_t *AXIS2_CALL
-axis2_generic_obj_create(const axutil_env_t *env)
+AXIS2_EXTERN axutil_generic_obj_t *AXIS2_CALL
+axutil_generic_obj_create(const axutil_env_t *env)
 {
-    axis2_generic_obj_t *generic_obj = NULL;
+    axutil_generic_obj_t *generic_obj = NULL;
     AXIS2_ENV_CHECK(env, NULL);
 
-    generic_obj = (axis2_generic_obj_t *) AXIS2_MALLOC(env->allocator,
-            sizeof(axis2_generic_obj_t));
+    generic_obj = (axutil_generic_obj_t *) AXIS2_MALLOC(env->allocator,
+            sizeof(axutil_generic_obj_t));
 
     if (! generic_obj)
     {
@@ -45,7 +45,7 @@
 }
 
 AXIS2_EXTERN void AXIS2_CALL
-axis2_generic_obj_free(axis2_generic_obj_t *generic_obj,
+axutil_generic_obj_free(axutil_generic_obj_t *generic_obj,
         const axutil_env_t *env)
 {
     AXIS2_ENV_CHECK(env, AXIS2_FAILURE);
@@ -71,7 +71,7 @@
 }
 
 AXIS2_EXTERN axis2_status_t AXIS2_CALL
-axis2_generic_obj_set_free_func(axis2_generic_obj_t *generic_obj,
+axutil_generic_obj_set_free_func(axutil_generic_obj_t *generic_obj,
         const axutil_env_t *env,
         AXIS2_FREE_VOID_ARG free_func)
 {
@@ -80,7 +80,7 @@
 }
 
 AXIS2_EXTERN axis2_status_t AXIS2_CALL
-axis2_generic_obj_set_value(axis2_generic_obj_t *generic_obj,
+axutil_generic_obj_set_value(axutil_generic_obj_t *generic_obj,
         const axutil_env_t *env,
         void *value)
 {
@@ -89,15 +89,15 @@
 }
 
 AXIS2_EXTERN void *AXIS2_CALL
-axis2_generic_obj_get_value(axis2_generic_obj_t *generic_obj,
+axutil_generic_obj_get_value(axutil_generic_obj_t *generic_obj,
         const axutil_env_t *env)
 {
     return generic_obj->value;
 }
 
 AXIS2_EXTERN axis2_status_t AXIS2_CALL
-axis2_generic_obj_set_type(
-    axis2_generic_obj_t *generic_obj,
+axutil_generic_obj_set_type(
+    axutil_generic_obj_t *generic_obj,
     const axutil_env_t *env,
     int type)
 {
@@ -106,8 +106,8 @@
 }
 
 AXIS2_EXTERN int AXIS2_CALL
-axis2_generic_obj_get_type(
-    axis2_generic_obj_t *generic_obj,
+axutil_generic_obj_get_type(
+    axutil_generic_obj_t *generic_obj,
     const axutil_env_t *env)
 {
     return generic_obj->type;

Modified: webservices/axis2/trunk/c/util/src/linked_list.c
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/util/src/linked_list.c?view=diff&rev=524229&r1=524228&r2=524229
==============================================================================
--- webservices/axis2/trunk/c/util/src/linked_list.c (original)
+++ webservices/axis2/trunk/c/util/src/linked_list.c Fri Mar 30 11:46:59 2007
@@ -15,10 +15,10 @@
  * limitations under the License.
  */
 
-#include <axis2_linked_list.h>
+#include <axutil_linked_list.h>
 #include <axis2_utils.h>
 
-struct axis2_linked_list
+struct axutil_linked_list
 {
     /**The number of elements in this list. */
     int size;
@@ -48,14 +48,14 @@
     int mod_count;
 };
 
-AXIS2_EXTERN axis2_linked_list_t *AXIS2_CALL
-axis2_linked_list_create(const axutil_env_t *env)
+AXIS2_EXTERN axutil_linked_list_t *AXIS2_CALL
+axutil_linked_list_create(const axutil_env_t *env)
 {
-    axis2_linked_list_t *linked_list = NULL;
+    axutil_linked_list_t *linked_list = NULL;
 
     AXIS2_ENV_CHECK(env, NULL);
 
-    linked_list = AXIS2_MALLOC(env->allocator, sizeof(axis2_linked_list_t));
+    linked_list = AXIS2_MALLOC(env->allocator, sizeof(axutil_linked_list_t));
     if (!linked_list)
     {
         AXIS2_ERROR_SET(env->error, AXIS2_ERROR_NO_MEMORY, AXIS2_FAILURE);
@@ -71,7 +71,7 @@
 }
 
 static entry_t *
-axis2_linked_list_create_entry(const axutil_env_t *env, void *data)
+axutil_linked_list_create_entry(const axutil_env_t *env, void *data)
 {
     entry_t *entry = (entry_t *) AXIS2_MALLOC(env->allocator, sizeof(entry_t));
     if (!entry)
@@ -87,7 +87,7 @@
 }
 
 static axis2_status_t
-axis2_linked_list_add_last_entry(axis2_linked_list_t *linked_list,
+axutil_linked_list_add_last_entry(axutil_linked_list_t *linked_list,
         const axutil_env_t *env,
         entry_t *e)
 {
@@ -111,7 +111,7 @@
 }
 
 AXIS2_EXTERN void AXIS2_CALL 
-axis2_linked_list_free(axis2_linked_list_t *linked_list,
+axutil_linked_list_free(axutil_linked_list_t *linked_list,
     const axutil_env_t *env)
 {
     entry_t *current = NULL, *next = NULL;
@@ -129,7 +129,7 @@
 }
 
 AXIS2_EXTERN entry_t * AXIS2_CALL
-axis2_linked_list_get_entry(axis2_linked_list_t *linked_list,
+axutil_linked_list_get_entry(axutil_linked_list_t *linked_list,
         const axutil_env_t *env,
         int n)
 {
@@ -158,7 +158,7 @@
 }
 
 AXIS2_EXTERN axis2_status_t AXIS2_CALL
-axis2_linked_list_remove_entry(axis2_linked_list_t *linked_list,
+axutil_linked_list_remove_entry(axutil_linked_list_t *linked_list,
         const axutil_env_t *env,
         entry_t *e)
 {
@@ -192,7 +192,7 @@
 }
 
 AXIS2_EXTERN axis2_bool_t AXIS2_CALL
-axis2_linked_list_check_bounds_inclusive(axis2_linked_list_t *linked_list,
+axutil_linked_list_check_bounds_inclusive(axutil_linked_list_t *linked_list,
         const axutil_env_t *env,
         int index)
 {
@@ -207,7 +207,7 @@
 }
 
 AXIS2_EXTERN axis2_bool_t AXIS2_CALL
-axis2_linked_list_check_bounds_exclusive(axis2_linked_list_t *linked_list,
+axutil_linked_list_check_bounds_exclusive(axutil_linked_list_t *linked_list,
         const axutil_env_t *env,
         int index)
 {
@@ -221,7 +221,7 @@
 }
 
 AXIS2_EXTERN void * AXIS2_CALL
-axis2_linked_list_get_first(axis2_linked_list_t *linked_list,
+axutil_linked_list_get_first(axutil_linked_list_t *linked_list,
         const axutil_env_t *env)
 {
     if (linked_list->size == 0)
@@ -234,7 +234,7 @@
 }
 
 AXIS2_EXTERN void * AXIS2_CALL
-axis2_linked_list_get_last(axis2_linked_list_t *linked_list,
+axutil_linked_list_get_last(axutil_linked_list_t *linked_list,
         const axutil_env_t *env)
 {
     AXIS2_ENV_CHECK(env, NULL);
@@ -249,7 +249,7 @@
 }
 
 AXIS2_EXTERN void * AXIS2_CALL
-axis2_linked_list_remove_first(axis2_linked_list_t *linked_list,
+axutil_linked_list_remove_first(axutil_linked_list_t *linked_list,
         const axutil_env_t *env)
 {
     void *r;
@@ -281,7 +281,7 @@
 }
 
 AXIS2_EXTERN void * AXIS2_CALL
-axis2_linked_list_remove_last(axis2_linked_list_t *linked_list,
+axutil_linked_list_remove_last(axutil_linked_list_t *linked_list,
         const axutil_env_t *env)
 {
     void *r = NULL;
@@ -312,7 +312,7 @@
 }
 
 AXIS2_EXTERN axis2_status_t AXIS2_CALL
-axis2_linked_list_add_first(axis2_linked_list_t *linked_list,
+axutil_linked_list_add_first(axutil_linked_list_t *linked_list,
         const axutil_env_t *env,
         void *o)
 {
@@ -320,7 +320,7 @@
     AXIS2_ENV_CHECK(env, AXIS2_FAILURE);
     AXIS2_PARAM_CHECK(env->error, o, AXIS2_FAILURE);
 
-    e = axis2_linked_list_create_entry(env, o);
+    e = axutil_linked_list_create_entry(env, o);
 
     linked_list->mod_count++;
     if (linked_list->size == 0)
@@ -339,7 +339,7 @@
 }
 
 AXIS2_EXTERN axis2_status_t AXIS2_CALL
-axis2_linked_list_add_last(axis2_linked_list_t *linked_list,
+axutil_linked_list_add_last(axutil_linked_list_t *linked_list,
         const axutil_env_t *env,
         void *o)
 {
@@ -347,12 +347,12 @@
     AXIS2_ENV_CHECK(env, AXIS2_FAILURE);
     AXIS2_PARAM_CHECK(env->error, o, AXIS2_FAILURE);
 
-    e = axis2_linked_list_create_entry(env, o);
-    return axis2_linked_list_add_last_entry(linked_list, env, e);
+    e = axutil_linked_list_create_entry(env, o);
+    return axutil_linked_list_add_last_entry(linked_list, env, e);
 }
 
 AXIS2_EXTERN axis2_bool_t AXIS2_CALL
-axis2_linked_list_contains(axis2_linked_list_t *linked_list,
+axutil_linked_list_contains(axutil_linked_list_t *linked_list,
         const axutil_env_t *env,
         void *o)
 {
@@ -371,27 +371,27 @@
 }
 
 AXIS2_EXTERN int AXIS2_CALL
-axis2_linked_list_size(axis2_linked_list_t *linked_list,
+axutil_linked_list_size(axutil_linked_list_t *linked_list,
         const axutil_env_t *env)
 {
     return linked_list->size;
 }
 
 AXIS2_EXTERN axis2_bool_t AXIS2_CALL
-axis2_linked_list_add(axis2_linked_list_t *linked_list,
+axutil_linked_list_add(axutil_linked_list_t *linked_list,
         const axutil_env_t *env,
         void *o)
 {
     entry_t *e;
     AXIS2_ENV_CHECK(env, AXIS2_FALSE);
     AXIS2_PARAM_CHECK(env->error, o, AXIS2_FALSE);
-    e = axis2_linked_list_create_entry(env, o);
-    return axis2_linked_list_add_last_entry(linked_list, env, e);
+    e = axutil_linked_list_create_entry(env, o);
+    return axutil_linked_list_add_last_entry(linked_list, env, e);
 }
 
 
 AXIS2_EXTERN axis2_bool_t AXIS2_CALL
-axis2_linked_list_remove(axis2_linked_list_t *linked_list,
+axutil_linked_list_remove(axutil_linked_list_t *linked_list,
         const axutil_env_t *env,
         void *o)
 {
@@ -404,7 +404,7 @@
     {
         if (o == e->data)
         {
-            return axis2_linked_list_remove_entry(linked_list, env, e);
+            return axutil_linked_list_remove_entry(linked_list, env, e);
         }
         e = e->next;
     }
@@ -413,7 +413,7 @@
 
 
 AXIS2_EXTERN axis2_status_t AXIS2_CALL
-axis2_linked_list_clear(axis2_linked_list_t *linked_list,
+axutil_linked_list_clear(axutil_linked_list_t *linked_list,
         const axutil_env_t *env)
 {
     if (linked_list->size > 0)
@@ -429,18 +429,18 @@
 
 
 AXIS2_EXTERN void * AXIS2_CALL
-axis2_linked_list_get(axis2_linked_list_t *linked_list,
+axutil_linked_list_get(axutil_linked_list_t *linked_list,
         const axutil_env_t *env,
         int index)
 {
     AXIS2_ENV_CHECK(env, NULL);
-    axis2_linked_list_check_bounds_exclusive(linked_list, env, index);
-    return axis2_linked_list_get_entry(linked_list, env, index)->data;
+    axutil_linked_list_check_bounds_exclusive(linked_list, env, index);
+    return axutil_linked_list_get_entry(linked_list, env, index)->data;
 }
 
 
 AXIS2_EXTERN void * AXIS2_CALL
-axis2_linked_list_set(axis2_linked_list_t *linked_list,
+axutil_linked_list_set(axutil_linked_list_t *linked_list,
         const axutil_env_t *env,
         int index, void *o)
 {
@@ -448,15 +448,15 @@
     void *old;
     AXIS2_ENV_CHECK(env, NULL);
     AXIS2_PARAM_CHECK(env->error, o, NULL);
-    axis2_linked_list_check_bounds_exclusive(linked_list, env, index);
-    e = axis2_linked_list_get_entry(linked_list, env, index);
+    axutil_linked_list_check_bounds_exclusive(linked_list, env, index);
+    e = axutil_linked_list_get_entry(linked_list, env, index);
     old = e->data;
     e->data = o;
     return old;
 }
 
 AXIS2_EXTERN axis2_status_t AXIS2_CALL
-axis2_linked_list_add_at_index(axis2_linked_list_t *linked_list,
+axutil_linked_list_add_at_index(axutil_linked_list_t *linked_list,
         const axutil_env_t *env,
         int index,
         void *o)
@@ -466,13 +466,13 @@
     AXIS2_ENV_CHECK(env, AXIS2_FAILURE);
     AXIS2_PARAM_CHECK(env->error, o, AXIS2_FAILURE);
 
-    axis2_linked_list_check_bounds_inclusive(linked_list, env, index);
-    e = axis2_linked_list_create_entry(env, o);
+    axutil_linked_list_check_bounds_inclusive(linked_list, env, index);
+    e = axutil_linked_list_create_entry(env, o);
 
     if (index < linked_list->size)
     {
         linked_list->mod_count++;
-        after = axis2_linked_list_get_entry(linked_list, env, index);
+        after = axutil_linked_list_get_entry(linked_list, env, index);
         e->next = after;
         e->previous = after->previous;
         if (after->previous == NULL)
@@ -484,28 +484,28 @@
     }
     else
     {
-        axis2_linked_list_add_last_entry(linked_list, env, e);
+        axutil_linked_list_add_last_entry(linked_list, env, e);
     }
 
     return AXIS2_SUCCESS;
 }
 
 AXIS2_EXTERN void * AXIS2_CALL
-axis2_linked_list_remove_at_index(axis2_linked_list_t *linked_list,
+axutil_linked_list_remove_at_index(axutil_linked_list_t *linked_list,
         const axutil_env_t *env,
         int index)
 {
     entry_t *e;
     AXIS2_ENV_CHECK(env, NULL);
-    axis2_linked_list_check_bounds_exclusive(linked_list, env, index);
-    e = axis2_linked_list_get_entry(linked_list, env, index);
-    axis2_linked_list_remove_entry(linked_list, env, e);
+    axutil_linked_list_check_bounds_exclusive(linked_list, env, index);
+    e = axutil_linked_list_get_entry(linked_list, env, index);
+    axutil_linked_list_remove_entry(linked_list, env, e);
     return e->data;
 }
 
 
 AXIS2_EXTERN int AXIS2_CALL
-axis2_linked_list_index_of(axis2_linked_list_t *linked_list,
+axutil_linked_list_index_of(axutil_linked_list_t *linked_list,
         const axutil_env_t *env,
         void *o)
 {
@@ -527,7 +527,7 @@
 
 
 AXIS2_EXTERN int AXIS2_CALL
-axis2_linked_list_last_index_of(axis2_linked_list_t *linked_list,
+axutil_linked_list_last_index_of(axutil_linked_list_t *linked_list,
         const axutil_env_t *env,
         void *o)
 {
@@ -549,7 +549,7 @@
 }
 
 AXIS2_EXTERN void ** AXIS2_CALL
-axis2_linked_list_to_array(axis2_linked_list_t *linked_list,
+axutil_linked_list_to_array(axutil_linked_list_t *linked_list,
         const axutil_env_t *env)
 {
     int i = 0;



---------------------------------------------------------------------
To unsubscribe, e-mail: axis-cvs-unsubscribe@ws.apache.org
For additional commands, e-mail: axis-cvs-help@ws.apache.org
--- webservices/axis2/trunk/c/util/include/axis2_log.h (original)
+++ webservices/axis2/trunk/c/util/include/axutil_log.h Fri Mar 30 11:46:59 2007
@@ -15,8 +15,8 @@
  * limitations under the License.
  */
 
-#ifndef AXIS2_LOG_H
-#define AXIS2_LOG_H
+#ifndef AXUTIL_LOG_H
+#define AXUTIL_LOG_H
 
 #include <axutil_allocator.h>
 
@@ -25,14 +25,14 @@
 {
 #endif
 
-    typedef struct axis2_log_ops axis2_log_ops_t;
-    typedef struct axis2_log axis2_log_t;
+    typedef struct axutil_log_ops axutil_log_ops_t;
+    typedef struct axutil_log axutil_log_t;
 
 
 #define AXIS2_LOG_SI __FILE__,__LINE__
 
     /**
-     * @defgroup axis2_log log
+     * @defgroup axutil_log log
      * @ingroup axis2_util
      * @{
      */
@@ -52,7 +52,7 @@
     /**
       * \brief Axis2 log levels
       */
-    typedef enum axis2_log_levels
+    typedef enum axutil_log_levels
     {
         /** Critical level, logs only critical errors */
         AXIS2_LOG_LEVEL_CRITICAL = 0,
@@ -66,14 +66,14 @@
         AXIS2_LOG_LEVEL_DEBUG,
         /** Trace level, Enable with compiler time option AXIS2_TRACE */
         AXIS2_LOG_LEVEL_TRACE
-    } axis2_log_levels_t;
+    } axutil_log_levels_t;
 
     /**
       * \brief Axis2 log ops struct
       *
       * Encapsulator struct for ops of axis2_log
       */
-    struct axis2_log_ops
+    struct axutil_log_ops
     {
 
         /**
@@ -83,7 +83,7 @@
 
         void(AXIS2_CALL *
         free)(axutil_allocator_t *allocator,
-            struct axis2_log *log);
+            struct axutil_log *log);
 
         /**
           * writes to the log
@@ -92,9 +92,9 @@
           * @return satus of the op. AXIS2_SUCCESS on success else AXIS2_FAILURE
           */
         void(AXIS2_CALL *
-        write)(axis2_log_t *log,
+        write)(axutil_log_t *log,
             const axis2_char_t *buffer,
-            axis2_log_levels_t level,
+            axutil_log_levels_t level,
             const axis2_char_t *file,
             const int line);
     };
@@ -104,76 +104,76 @@
       *
       * Log is the encapsulating struct for all log related data and ops
       */
-    struct axis2_log
+    struct axutil_log
     {
         /** Log related ops */
-        const axis2_log_ops_t *ops;
+        const axutil_log_ops_t *ops;
         /** Log level */
-        axis2_log_levels_t level;
+        axutil_log_levels_t level;
         /** Is logging enabled? */
         axis2_bool_t enabled;
 
     };
 
     AXIS2_EXTERN void AXIS2_CALL
-    axis2_log_impl_log_critical(axis2_log_t *log,
+    axutil_log_impl_log_critical(axutil_log_t *log,
             const axis2_char_t *filename,
             const int linenumber,
             const axis2_char_t *format, ...);
 
     AXIS2_EXTERN void AXIS2_CALL
-    axis2_log_impl_log_error(axis2_log_t *log,
+    axutil_log_impl_log_error(axutil_log_t *log,
             const axis2_char_t *filename,
             const int linenumber,
             const axis2_char_t *format, ...);
 
     AXIS2_EXTERN void AXIS2_CALL
-    axis2_log_impl_log_warning(axis2_log_t *log,
+    axutil_log_impl_log_warning(axutil_log_t *log,
             const axis2_char_t *filename,
             const int linenumber,
             const axis2_char_t *format, ...);
 
     AXIS2_EXTERN void AXIS2_CALL
-    axis2_log_impl_log_info(axis2_log_t *log,
+    axutil_log_impl_log_info(axutil_log_t *log,
             const axis2_char_t *format, ...);
 
     AXIS2_EXTERN void AXIS2_CALL
-    axis2_log_impl_log_debug(axis2_log_t *log,
+    axutil_log_impl_log_debug(axutil_log_t *log,
             const axis2_char_t *filename,
             const int linenumber,
             const axis2_char_t *format, ...);
 
     AXIS2_EXTERN void AXIS2_CALL
-    axis2_log_impl_log_trace(axis2_log_t *log,
+    axutil_log_impl_log_trace(axutil_log_t *log,
             const axis2_char_t *filename,
             const int linenumber,
             const axis2_char_t *format, ...);
 
     AXIS2_EXTERN void AXIS2_CALL 
-    axis2_log_free(axutil_allocator_t *allocator,
-        struct axis2_log *log);
+    axutil_log_free(axutil_allocator_t *allocator,
+        struct axutil_log *log);
 
     AXIS2_EXTERN void AXIS2_CALL
-    axis2_log_write(axis2_log_t *log,
+    axutil_log_write(axutil_log_t *log,
         const axis2_char_t *buffer,
-        axis2_log_levels_t level,
+        axutil_log_levels_t level,
         const axis2_char_t *file,
         const int line);
 
 #define AXIS2_LOG_FREE(allocator, log) \
-      axis2_log_free(allocator, log)
+      axutil_log_free(allocator, log)
 
 #define AXIS2_LOG_WRITE(log, buffer, level, file) \
-      axis2_log_write(log, buffer, level, file, AXIS2_LOG_SI)
+      axutil_log_write(log, buffer, level, file, AXIS2_LOG_SI)
 
-#define AXIS2_LOG_DEBUG axis2_log_impl_log_debug
-#define AXIS2_LOG_INFO axis2_log_impl_log_info
-#define AXIS2_LOG_WARNING axis2_log_impl_log_warning
-#define AXIS2_LOG_ERROR axis2_log_impl_log_error
-#define AXIS2_LOG_CRITICAL axis2_log_impl_log_critical
+#define AXIS2_LOG_DEBUG axutil_log_impl_log_debug
+#define AXIS2_LOG_INFO axutil_log_impl_log_info
+#define AXIS2_LOG_WARNING axutil_log_impl_log_warning
+#define AXIS2_LOG_ERROR axutil_log_impl_log_error
+#define AXIS2_LOG_CRITICAL axutil_log_impl_log_critical
 
 #ifdef AXIS2_TRACE
-#define AXIS2_LOG_TRACE axis2_log_impl_log_trace
+#define AXIS2_LOG_TRACE axutil_log_impl_log_trace
 #else
 # ifdef HAVE_GNUC_VARARGS
 #  define AXIS2_LOG_TRACE(params, args ...)
@@ -182,9 +182,9 @@
 # elif __STDC__ && __STDC_VERSION > 199901L
 #  define AXIS2_LOG_TRACE(params, ...)
 # elif WIN32
-#  define AXIS2_LOG_TRACE axis2_log_impl_log_trace
+#  define AXIS2_LOG_TRACE axutil_log_impl_log_trace
 # else
-#  define AXIS2_LOG_TRACE axis2_log_impl_log_trace
+#  define AXIS2_LOG_TRACE axutil_log_impl_log_trace
 # endif
 #endif
 
@@ -66,14 +66,14 @@
       * \brief Axis2 log ops struct
       *
-      * Encapsulator struct for ops of axis2_log
+      * Encapsulator struct for ops of axutil_log
       */

Copied: webservices/axis2/trunk/c/util/include/axutil_log_default.h (from r524179, webservices/axis2/trunk/c/util/include/axis2_log_default.h)
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/util/include/axutil_log_default.h?view=diff&rev=524229&p1=webservices/axis2/trunk/c/util/include/axis2_log_default.h&r1=524179&p2=webservices/axis2/trunk/c/util/include/axutil_log_default.h&r2=524229
==============================================================================